# if your're using this script, you have to provide an on_error function
# and you must have included functions.sh

# $1 either install or upgrade
# $2 empty to install all packages inside 'packages' or a string with package names, e.g. "php5-pgsql php5-gd"
function install_packages() 
{
    sources_list="/etc/apt/sources.list"
    if [ -d packages ]; then
        if [ -n "$(dpkg -l '*' | grep '^i[^iU]')" -o -n "$(dpkg -C)" ]; then
            dpkgl=`dpkg -l '*' | grep '^i[^iU]'`
            dpkgc=`dpkg -C`
            log_error "Debian packages can't be installed: ${dpkgl} ${dpkgc}" 
            on_error
            exit 1
        fi
        cd packages
        if [ "$2" ]; then
            installed_packages="$2"
        else
            installed_packages=`ls -1 *.deb | cut -d"_" -f1 | xargs`
        fi
        cd ..
        if [ ! -n "${installed_packages}" ]; then
            log_msg "No debian packages to install"
        else
            log_msg "Install debian packages ${installed_packages}"
            apt-ftparchive packages packages/ > packages/Packages
            sed -e 's/packages\///' -i packages/Packages
            gzip -9c packages/Packages > packages/Packages.gz
            rm packages/Packages
            mv packages/Packages.gz /var/cache/apt/archives
            mv packages/*.deb /var/cache/apt/archives
            mv ${sources_list} ${sources_list}.tmp
            echo "deb file:///var/cache/apt/archives /" > ${sources_list}
            apt-get update
            tmp=""
            if [ "$1" = "install" ]; then
                installed_tmp=""
                for d in $installed_packages; do
                    p_installed=`dpkg -l | egrep -oe "[a-zA-Z]{2}[ ]*$d"`
                    if [ -z "$p_installed" ]; then
                        installed_tmp="$installed_tmp $d"
                    else
                        log_msg "Package $d already installed"
                    fi
                done
                apt-get -y --force-yes install ${installed_packages}
                apt_res=$?
                installed_packages=$installed_tmp
            elif [ "$1" = "upgrade" ]; then
                installed_packages=""
                tmp=`apt-get -y --force-yes upgrade`
                apt_res=$?
                echo $tmp
            fi
            apt-get clean
            mv ${sources_list}.tmp ${sources_list}
            if [ ! ${apt_res} -eq 0 ]; then
                log_error "Installation of debian packages failed"
                on_error
                exit 1
            fi
            if echo $tmp | grep "The following packages have been kept back" >/dev/null
            then
                if [ "$1" = "upgrade" ]; then
                    missing=`echo $tmp | sed 's/.*have been kept back: \+\(.*\) \+The \+following \+packages \+will \+be \+upgraded.*/\1/'`
                    log_msg "Some package dependencies are missing!"
                    tmp_file="/var/www/innovaphone/log/missing_packages.log"			 
                    echo ${missing} > $tmp_file
                    chmod 755 $tmp_file
                    chown www-data:www-data $tmp_file
                fi
            fi
        fi
    else
        log_msg "No debian packages to install"
    fi
}

